/*
 * Enhydra Java Application Server
 * The Initial Developer of the Original Code is Lutris Technologies Inc.
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc.
 * All Rights Reserved.
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License.
 *
 * $Id: RootPanel.java,v 1.1 2000/05/30 07:31:17 pmahar Exp $
 */
package org.enhydra.kelp.common.wizard.importer;

// Kelp imports
import org.enhydra.kelp.common.ValidationUtil;
import org.enhydra.kelp.common.ValidationException;
import org.enhydra.kelp.common.swing.SwingUtil;

// Standard imports
import javax.swing.*;
import javax.swing.border.*;
import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.beans.*;
import java.io.File;

/**
 * Panel for entering the default options: project name, package
 * and destination.
 *
 * @author Paul Mahar
 * @version $Revision: 1.1 $
 */
public class RootPanel extends ImporterPanel {
    transient private JPanel               panelRoot;
    transient private JTextField           textRoot;
    transient private JButton              buttonRoot;

    //
    transient private JPanel              panelFiller;
    transient private GridBagLayout       layoutMain;
    transient private GridBagLayout       layoutRoot;
    transient private LocalButtonListener buttonListener;
    transient private TitledBorder        borderRoot;

    /**
     * Create default option panel 1 for entering the
     * following default options: project name, package and
     * destination.
     */
    public RootPanel() {
        try {
            jbInit();
            pmInit();
        } catch (Exception ex) {
            ex.printStackTrace();
        }
    }

    /**
     * Read project name, package and destination values from the
     * option set into the swing controls.
     *
     * @exception GeneratorException
     * Thrown if unable to update Swing controls with option set values.
     */
    public void readOptions() {
        File file;

        // project root
        file = getImporter().getRoot();
        if (file == null) {
          textRoot.setText(new String());
        } else {
          textRoot.setText(file.getAbsolutePath());
        }
    }

    /**
     * Write project name, package and destination values from the
     * swing controls into the option set.
     *
     * @exception GeneratorException
     * Thrown if unable to update option set from Swing control values.
     */
    public void writeOptions() throws ValidationException {
        File file = null;

        if (getImporter() == null) {
          throw new ValidationException("Importer not set: cannot write options");
        }
        // root
        file = new File(textRoot.getText());
        getImporter().setRoot(file);
    }

    /**
     * Validate project name, package and destination values
     * in the swing controls.
     *
     * @exception ValidationException
     * Thrown if swing control values are not valid for the
     * current option set.
     */
    public void validateOptions() throws ValidationException {
        String value = new String();

        // project name
        value = textRoot.getText().trim();
        if (!ValidationUtil.isDirectory(value)) {
            throw new ValidationException("Root directory is not valid. "
                                          + "Directory not found.");
        }

    }

    /**
     * Get the title to use on the current page.
     *
     * @return
     * A string to place at the top of a CodeGen wizard panel.
     */
    public String getPageTitle() {
        return "Project Root";
    }

    /**
     * Get the instructions for entering option values for the
     * current page.
     *
     * @return
     * A string to place below the page title.
     */
    public String getInstructions() {
        StringBuffer buf = new StringBuffer();

        buf.append("Enter the root directory for the files you would ");
        buf.append("like to import into the current project. The wizard ");
        buf.append("will all files within the root and below to the ");
        buf.append("project.");
        return buf.toString();
    }

    // /
    // /

    /**
     * Method declaration
     *
     *
     * @exception Exception
     *
     * @see
     */
    private void jbInit() throws Exception {
        textRoot =
            (JTextField) Beans.instantiate(getClass().getClassLoader(),
                                           JTextField.class.getName());
        panelRoot = (JPanel) Beans.instantiate(getClass().getClassLoader(),
                                               JPanel.class.getName());

        layoutRoot =
            (GridBagLayout) Beans.instantiate(getClass().getClassLoader(),
                                              GridBagLayout.class.getName());

        buttonRoot = (JButton) Beans.instantiate(getClass().getClassLoader(),
                                                JButton.class.getName());

        layoutMain =
            (GridBagLayout) Beans.instantiate(getClass().getClassLoader(),
                                              GridBagLayout.class.getName());
        panelFiller = (JPanel) Beans.instantiate(getClass().getClassLoader(),
                                                 JPanel.class.getName());
        textRoot.setText("ROOT1");
        buttonRoot.setText("Set...");

        panelRoot.setLayout(layoutRoot);
        panelRoot.add(textRoot,
                      new GridBagConstraints(0, 0, 1, 1, 0.1, 0.1,
                                             GridBagConstraints.WEST,
                                             GridBagConstraints.HORIZONTAL,
                                             new Insets(5, 5, 5, 5), 0, 0));
        panelRoot.add(buttonRoot,
                      new GridBagConstraints(1, 0, 1, 2, 0.0, 0.0,
                                             GridBagConstraints.CENTER,
                                             GridBagConstraints.NONE,
                                             new Insets(5, 5, 5, 20), 0, 0));


        this.setLayout(layoutMain);
        this.add(panelRoot,
                 new GridBagConstraints(0, 0, 1, 1, 0.1, 0.1,
                                        GridBagConstraints.CENTER,
                                        GridBagConstraints.BOTH,
                                        new Insets(5, 5, 5, 5), 0, 0));
    }

    /**
     * Method declaration
     *
     *
     * @see
     */
    private void pmInit() {
        Border border = BorderFactory.createEtchedBorder();

        borderRoot = BorderFactory.createTitledBorder(border);
        borderRoot.setTitle("Project root");

        panelRoot.setBorder(borderRoot);

        buttonListener = new LocalButtonListener();
        buttonRoot.addActionListener(buttonListener);
        textRoot.setText(new String());
    }

    /**
     * Method declaration
     *
     *
     * @see
     */
    private void browseForDirectory() {
        File dir = null;

        dir =
            SwingUtil.getDirectoryChoice(this, textRoot.getText(),
                                         "Choose project root directory");
        if (dir != null) {
            textRoot.setText(dir.getAbsolutePath());
        }
    }

    /**
     * Class declaration
     *
     *
     * @author Paul Mahar
     * @version $Revision: 1.1 $
     */
    private class LocalButtonListener implements ActionListener {

        /**
         * Method declaration
         *
         *
         * @param event
         *
         * @see
         */
        public void actionPerformed(ActionEvent event) {
            browseForDirectory();
        }

    }
}
